@@ -1,7 +1,8 @@
 use crate::{RuleConfig, SerializableRule, SerializableRuleConfig, SerializableRuleCore, Severity};
 
 use ast_grep_core::language::Language;
-use ast_grep_core::{AstGrep, Doc, Matcher, Node, NodeMatch};
+use ast_grep_core::matcher::{Matcher, MatcherExt};
+use ast_grep_core::{AstGrep, Doc, Node, NodeMatch};
 
 use std::collections::{HashMap, HashSet};
 
@@ -38,7 +39,8 @@ impl<'t, D: Doc> ScanResultInner<'t, D> {
       if separate_fix {
         diffs.extend(self.unused_suppressions.into_iter().map(|nm| (rule, nm)));
         diffs.sort_unstable_by_key(|(_, nm)| nm.range().start);
-      } else {
+      } else if !self.unused_suppressions.is_empty() {
+        // do not push empty suppression to matches
         let mut supprs = self.unused_suppressions;
         supprs.sort_unstable_by_key(|nm| nm.range().start);
         matches.push((rule, supprs));
