@@ -16,7 +16,7 @@ use serde_yaml::{with::singleton_map_recursive::deserialize, Deserializer};
 use thiserror::Error;
 
 use std::borrow::Cow;
-use std::collections::{HashMap, HashSet};
+use std::collections::HashMap;
 use std::ops::{Deref, DerefMut};
 
 #[derive(Serialize, Deserialize, Clone, Default, JsonSchema, Debug)]
@@ -120,54 +120,33 @@ impl<L: Language> SerializableRuleConfig<L> {
     // every RuleConfig has one rewriters, and the rewriter is shared between sub-rules
     // all RuleConfigs has one common globals
     // every sub-rule has one util
-    let rewriters = GlobalRules::default();
-    let env = DeserializeEnv::new(self.language.clone())
-      .with_globals(globals)
-      .with_rewriters(&rewriters);
-    let rule = self.core.get_matcher(env)?;
-    self.register_rewriters(&rule, globals, &rewriters)?;
+    let env = DeserializeEnv::new(self.language.clone()).with_globals(globals);
+    let rule = self.core.get_matcher(env.clone())?;
+    self.register_rewriters(&rule, env)?;
     Ok(rule)
   }
 
   fn register_rewriters(
     &self,
     rule: &RuleCore<L>,
-    globals: &GlobalRules<L>,
-    rewriters: &GlobalRules<L>,
+    env: DeserializeEnv<L>,
   ) -> Result<(), RuleConfigError> {
     let Some(ser) = &self.rewriters else {
       return Ok(());
     };
+    let reg = &env.registration;
     let vars = rule.defined_vars();
     for val in ser {
       if val.core.fix.is_none() {
         return Err(RuleConfigError::NoFixInRewriter(val.id.clone()));
       }
-      self
-        .register_one_rewriter(val, &vars, globals, rewriters)
+      let rewriter = val
+        .core
+        .get_matcher_with_hint(env.clone(), CheckHint::Rewriter(&vars))
         .map_err(|e| RuleConfigError::Rewriter(e, val.id.clone()))?;
+      reg.insert_rewriter(&val.id, rewriter);
     }
-    check_rewriters_in_transform(rule, rewriters)?;
-    Ok(())
-  }
-
-  fn register_one_rewriter(
-    &self,
-    val: &SerializableRewriter,
-    vars: &HashSet<&str>,
-    globals: &GlobalRules<L>,
-    rewriters: &GlobalRules<L>,
-  ) -> Result<(), RuleCoreError> {
-    // NB should inherit env from matcher to inherit utils
-    // TODO: optimize duplicate env creation/util registration
-    let env = DeserializeEnv::new(self.language.clone())
-      .with_globals(globals)
-      .with_rewriters(rewriters);
-    let env = self.get_deserialize_env(env)?;
-    let rewriter = val
-      .core
-      .get_matcher_with_hint(env, CheckHint::Rewriter(vars))?;
-    rewriters.insert(&val.id, rewriter).expect("should work");
+    check_rewriters_in_transform(rule, reg.get_rewriters())?;
     Ok(())
   }
 }
