@@ -60,14 +60,10 @@ pub struct SerializableRuleCore {
 }
 
 impl SerializableRuleCore {
-  pub(crate) fn get_deserialize_env<L: Language>(
-    &self,
-    env: DeserializeEnv<L>,
-  ) -> RResult<DeserializeEnv<L>> {
+  /// This function assumes env's local is empty.
+  fn get_deserialize_env<L: Language>(&self, env: DeserializeEnv<L>) -> RResult<DeserializeEnv<L>> {
     if let Some(utils) = &self.utils {
-      let env = env
-        .register_local_utils(utils)
-        .map_err(RuleCoreError::Utils)?;
+      let env = env.with_utils(utils).map_err(RuleCoreError::Utils)?;
       Ok(env)
     } else {
       Ok(env)
@@ -230,13 +226,12 @@ impl<L: Language> RuleCore<L> {
     }
     if let Some(trans) = &self.transform {
       let rewriters = self.registration.get_rewriters();
-      let rewriters = rewriters.read();
       let env = env.to_mut();
       if let Some(enclosing) = enclosing_env {
-        trans.apply_transform(env, &rewriters, enclosing);
+        trans.apply_transform(env, rewriters, enclosing);
       } else {
         let enclosing = env.clone();
-        trans.apply_transform(env, &rewriters, &enclosing);
+        trans.apply_transform(env, rewriters, &enclosing);
       };
     }
     Some(ret)
@@ -280,9 +275,9 @@ impl<L: Language> Matcher<L> for RuleCore<L> {
 #[cfg(test)]
 mod test {
   use super::*;
+  use crate::from_str;
   use crate::rule::referent_rule::{ReferentRule, ReferentRuleError};
   use crate::test::TypeScript;
-  use crate::{from_str, GlobalRules};
   use ast_grep_core::matcher::{Pattern, RegexMatcher};
 
   fn get_matcher(src: &str) -> RResult<RuleCore<TypeScript>> {
@@ -400,22 +395,21 @@ transform:
     assert_eq!(matched, "2");
   }
 
-  fn get_rewriters() -> GlobalRules<TypeScript> {
+  fn get_rewriters() -> (&'static str, RuleCore<TypeScript>) {
     // NOTE: initialize a DeserializeEnv here is not 100% correct
     // it does not inherit global rules or local rules
     let env = DeserializeEnv::new(TypeScript::Tsx);
-    let ret = GlobalRules::default();
     let rewriter: SerializableRuleCore =
       from_str("{rule: {kind: number, pattern: $REWRITE}, fix: yjsnp}").expect("should parse");
     let rewriter = rewriter.get_matcher(env).expect("should work");
-    ret.insert("re", rewriter).expect("should work");
-    ret
+    ("re", rewriter)
   }
 
   #[test]
   fn test_rewriter_writing_to_env() {
-    let rewriters = get_rewriters();
-    let env = DeserializeEnv::new(TypeScript::Tsx).with_rewriters(&rewriters);
+    let (id, rewriter) = get_rewriters();
+    let env = DeserializeEnv::new(TypeScript::Tsx);
+    env.registration.insert_rewriter(id, rewriter);
     let ser_rule: SerializableRuleCore = from_str(
       r"
 rule: {pattern: $A = $B}
