@@ -65,7 +65,7 @@ fn create_template(tmpl: &str, mv_char: char, transforms: &[String]) -> Template
     {
       fragments.push(tmpl[len..len + offset + i].to_string());
       // NB we have to count ident of the full string
-      let indent = get_indent_at_offset::<String>(tmpl[..len + offset + i].as_bytes());
+      let indent = get_indent_at_offset::<String>(&tmpl.as_bytes()[..len + offset + i]);
       vars.push((meta_var, indent));
       len += skipped + offset + i;
       offset = 0;
@@ -119,8 +119,11 @@ where
 {
   let (source, range) = match var {
     MetaVarExtract::Transformed(name) => {
+      // transformed source does not have range, directly return bytes
       let source = env.get_transformed(name)?;
-      return Some(Cow::Borrowed(source));
+      let de_intended = DeindentedExtract::MultiLine(source, 0);
+      let bytes = indent_lines::<D::Source>(*indent, de_intended);
+      return Some(bytes);
     }
     MetaVarExtract::Single(name) => {
       let replaced = env.get_match(name)?;
@@ -158,7 +161,7 @@ mod test {
 
   use super::*;
   use crate::language::{Language, Tsx};
-  use crate::meta_var::MetaVarEnv;
+  use crate::meta_var::{MetaVarEnv, MetaVariable};
   use crate::Pattern;
   use std::collections::HashMap;
 
@@ -343,6 +346,22 @@ if (true) {
     );
   }
 
+  #[test]
+  fn test_replace_rewriter() {
+    let tf = TemplateFix::with_transform("if (a)\n  $A", &Tsx, &["A".to_string()]);
+    let mut env = MetaVarEnv::new();
+    env.insert_transformation(
+      &MetaVariable::Multiple,
+      "A",
+      "if (b)\n  foo".bytes().collect(),
+    );
+    let dummy = Tsx.ast_grep("dummy");
+    let node_match = NodeMatch::new(dummy.root(), env.clone());
+    let bytes = tf.generate_replacement(&node_match);
+    let ret = String::from_utf8(bytes).expect("replacement must be valid utf-8");
+    assert_eq!("if (a)\n  if (b)\n    foo", ret);
+  }
+
   #[test]
   fn test_nested_matching_replace() {
     // TODO impossible, we don't support nested replacement
