@@ -5,11 +5,7 @@ import {
   ts,
   tsx,
   html,
-  Lang,
   parseFiles,
-  parseAsync,
-  findInFiles,
-  parse as parseWithLang,
 } from '../index'
 const { parse, kind } = js
 const parseMulti = countedPromise(parseFiles)
@@ -384,42 +380,6 @@ function countedPromise<F extends (t: any, cb: any) => Promise<number>>(
   }
 }
 
-test('parse python', t => {
-  const sg = parseWithLang(Lang.Python, 'print("hello world")')
-  const node = sg.root().find('print')
-  t.deepEqual(node!.range(), {
-    start: { line: 0, column: 0, index: 0 },
-    end: { line: 0, column: 5, index: 5 },
-  })
-})
-
-test('parse python async', async t => {
-  const sg = await parseAsync(Lang.Python, 'print("hello world")')
-  const node = sg.root().find('print')
-  t.deepEqual(node!.range(), {
-    start: { line: 0, column: 0, index: 0 },
-    end: { line: 0, column: 5, index: 5 },
-  })
-})
-
-test('find rust', async t => {
-  let changed = false
-  const counted = countedPromise((t, cb) => findInFiles(Lang.Rust, t, cb))
-  const num = await counted(
-    {
-      paths: ['./'],
-      matcher: {
-        rule: { pattern: 'ast_grep_core' },
-      },
-    },
-    () => {
-      changed = true
-    },
-  )
-  t.assert(changed)
-  t.assert(num > 0)
-})
-
 test('find node by range', t => {
   const sg = parse(
     'const message = `This is a multiline message with unicode characters\nÜbergang\nدرود\n🙌\n`;',
@@ -460,7 +420,7 @@ test('check if a node follows another using pattern', t => {
 test('check if a node follows another using config', t => {
   const sg = parse('const a = 1; const b = 2;')
   const match = sg.root().find('const a = 1')
-  t.assert(match!.follows({ rule: { pattern: 'const b = 2' }}) === false) 
+  t.assert(match!.follows({ rule: { pattern: 'const b = 2' }}) === false)
   t.assert(sg.root().find('const b = 2')!.follows({ rule: { pattern: 'const a = 1' }}))
 })
 
@@ -504,4 +464,4 @@ test('check if a node has another using config', t => {
   const match = sg.root().find('if (true) { $$$ }')
   t.assert(match!.has({ rule: { pattern: 'const x = 1' }}))
   t.assert(match!.has({ rule: { pattern: 'const y = 2' }}) === false)
-})
+})
\ No newline at end of file
